# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: name_registry_event.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19name_registry_event.proto\"\xc9\x01\n\x11NameRegistryEvent\x12\x14\n\x0c\x62lock_number\x18\x01 \x01(\r\x12\x12\n\nblock_hash\x18\x02 \x01(\x0c\x12\x18\n\x10transaction_hash\x18\x03 \x01(\x0c\x12\x11\n\tlog_index\x18\x04 \x01(\r\x12\r\n\x05\x66name\x18\x05 \x01(\x0c\x12\x0c\n\x04\x66rom\x18\x06 \x01(\x0c\x12\n\n\x02to\x18\x07 \x01(\x0c\x12$\n\x04type\x18\x08 \x01(\x0e\x32\x16.NameRegistryEventType\x12\x0e\n\x06\x65xpiry\x18\t \x01(\r*\x85\x01\n\x15NameRegistryEventType\x12!\n\x1dNAME_REGISTRY_EVENT_TYPE_NONE\x10\x00\x12%\n!NAME_REGISTRY_EVENT_TYPE_TRANSFER\x10\x01\x12\"\n\x1eNAME_REGISTRY_EVENT_TYPE_RENEW\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'name_registry_event_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_NAMEREGISTRYEVENTTYPE']._serialized_start=234
  _globals['_NAMEREGISTRYEVENTTYPE']._serialized_end=367
  _globals['_NAMEREGISTRYEVENT']._serialized_start=30
  _globals['_NAMEREGISTRYEVENT']._serialized_end=231
# @@protoc_insertion_point(module_scope)



import numpy as np
from typing import Dict
from transformers import (
    DataCollatorWithPadding,
    EvalPrediction,
    Trainer,
    AutoModelForSequenceClassification,
)
from sklearn.metrics import f1_score, accuracy_score
from farglot.pretrained import default_auto_config, load_model_and_tokenizer

id2label = {0: "NEGATIVE", 1: "POSITIVE"}


def compute_metrics(eval_pred: EvalPrediction) -> Dict:
    logits, label_ids = eval_pred
    predictions = np.argmax(logits, axis=-1)
    return {
        "accuracy": accuracy_score(label_ids, predictions),
        "f1": f1_score(label_ids, predictions),
    }


def binary_classifier(base_model: str) -> Trainer:
    model, tokenizer = load_model_and_tokenizer(
        base_model=base_model,
        auto_model_class=AutoModelForSequenceClassification,
        config=default_auto_config(base_model, id2label),
    )

    return Trainer(
        model=model,
        tokenizer=tokenizer,
        data_collator=DataCollatorWithPadding(tokenizer=tokenizer, padding="longest"),
        compute_metrics=compute_metrics,
    )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: message.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import farglot.__farcaster.generated.username_proof_pb2 as username__proof__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\rmessage.proto\x1a\x14username_proof.proto"\xa4\x01\n\x07Message\x12\x1a\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x0c.MessageData\x12\x0c\n\x04hash\x18\x02 \x01(\x0c\x12 \n\x0bhash_scheme\x18\x03 \x01(\x0e\x32\x0b.HashScheme\x12\x11\n\tsignature\x18\x04 \x01(\x0c\x12*\n\x10signature_scheme\x18\x05 \x01(\x0e\x32\x10.SignatureScheme\x12\x0e\n\x06signer\x18\x06 \x01(\x0c"\xcf\x04\n\x0bMessageData\x12\x1a\n\x04type\x18\x01 \x01(\x0e\x32\x0c.MessageType\x12\x0b\n\x03\x66id\x18\x02 \x01(\x04\x12\x11\n\ttimestamp\x18\x03 \x01(\r\x12"\n\x07network\x18\x04 \x01(\x0e\x32\x11.FarcasterNetwork\x12%\n\rcast_add_body\x18\x05 \x01(\x0b\x32\x0c.CastAddBodyH\x00\x12+\n\x10\x63\x61st_remove_body\x18\x06 \x01(\x0b\x32\x0f.CastRemoveBodyH\x00\x12&\n\rreaction_body\x18\x07 \x01(\x0b\x32\r.ReactionBodyH\x00\x12K\n!verification_add_eth_address_body\x18\t \x01(\x0b\x32\x1e.VerificationAddEthAddressBodyH\x00\x12;\n\x18verification_remove_body\x18\n \x01(\x0b\x32\x17.VerificationRemoveBodyH\x00\x12)\n\x0fsigner_add_body\x18\x0b \x01(\x0b\x32\x0e.SignerAddBodyH\x00\x12\'\n\x0euser_data_body\x18\x0c \x01(\x0b\x32\r.UserDataBodyH\x00\x12/\n\x12signer_remove_body\x18\r \x01(\x0b\x32\x11.SignerRemoveBodyH\x00\x12\x1e\n\tlink_body\x18\x0e \x01(\x0b\x32\t.LinkBodyH\x00\x12-\n\x13username_proof_body\x18\x0f \x01(\x0b\x32\x0e.UserNameProofH\x00\x42\x06\n\x04\x62ody";\n\rSignerAddBody\x12\x0e\n\x06signer\x18\x01 \x01(\x0c\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_name""\n\x10SignerRemoveBody\x12\x0e\n\x06signer\x18\x01 \x01(\x0c":\n\x0cUserDataBody\x12\x1b\n\x04type\x18\x01 \x01(\x0e\x32\r.UserDataType\x12\r\n\x05value\x18\x02 \x01(\t";\n\x05\x45mbed\x12\r\n\x03url\x18\x01 \x01(\tH\x00\x12\x1a\n\x07\x63\x61st_id\x18\x02 \x01(\x0b\x32\x07.CastIdH\x00\x42\x07\n\x05\x65mbed"\xbf\x01\n\x0b\x43\x61stAddBody\x12\x19\n\x11\x65mbeds_deprecated\x18\x01 \x03(\t\x12\x10\n\x08mentions\x18\x02 \x03(\x04\x12!\n\x0eparent_cast_id\x18\x03 \x01(\x0b\x32\x07.CastIdH\x00\x12\x14\n\nparent_url\x18\x07 \x01(\tH\x00\x12\x0c\n\x04text\x18\x04 \x01(\t\x12\x1a\n\x12mentions_positions\x18\x05 \x03(\r\x12\x16\n\x06\x65mbeds\x18\x06 \x03(\x0b\x32\x06.EmbedB\x08\n\x06parent"%\n\x0e\x43\x61stRemoveBody\x12\x13\n\x0btarget_hash\x18\x01 \x01(\x0c"#\n\x06\x43\x61stId\x12\x0b\n\x03\x66id\x18\x01 \x01(\x04\x12\x0c\n\x04hash\x18\x02 \x01(\x0c"n\n\x0cReactionBody\x12\x1b\n\x04type\x18\x01 \x01(\x0e\x32\r.ReactionType\x12!\n\x0etarget_cast_id\x18\x02 \x01(\x0b\x32\x07.CastIdH\x00\x12\x14\n\ntarget_url\x18\x03 \x01(\tH\x00\x42\x08\n\x06target"[\n\x1dVerificationAddEthAddressBody\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12\x15\n\reth_signature\x18\x02 \x01(\x0c\x12\x12\n\nblock_hash\x18\x03 \x01(\x0c")\n\x16VerificationRemoveBody\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c"l\n\x08LinkBody\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x1d\n\x10\x64isplayTimestamp\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x14\n\ntarget_fid\x18\x03 \x01(\x04H\x00\x42\x08\n\x06targetB\x13\n\x11_displayTimestamp*:\n\nHashScheme\x12\x14\n\x10HASH_SCHEME_NONE\x10\x00\x12\x16\n\x12HASH_SCHEME_BLAKE3\x10\x01*g\n\x0fSignatureScheme\x12\x19\n\x15SIGNATURE_SCHEME_NONE\x10\x00\x12\x1c\n\x18SIGNATURE_SCHEME_ED25519\x10\x01\x12\x1b\n\x17SIGNATURE_SCHEME_EIP712\x10\x02*\xaa\x03\n\x0bMessageType\x12\x15\n\x11MESSAGE_TYPE_NONE\x10\x00\x12\x19\n\x15MESSAGE_TYPE_CAST_ADD\x10\x01\x12\x1c\n\x18MESSAGE_TYPE_CAST_REMOVE\x10\x02\x12\x1d\n\x19MESSAGE_TYPE_REACTION_ADD\x10\x03\x12 \n\x1cMESSAGE_TYPE_REACTION_REMOVE\x10\x04\x12\x19\n\x15MESSAGE_TYPE_LINK_ADD\x10\x05\x12\x1c\n\x18MESSAGE_TYPE_LINK_REMOVE\x10\x06\x12-\n)MESSAGE_TYPE_VERIFICATION_ADD_ETH_ADDRESS\x10\x07\x12$\n MESSAGE_TYPE_VERIFICATION_REMOVE\x10\x08\x12\x1b\n\x17MESSAGE_TYPE_SIGNER_ADD\x10\t\x12\x1e\n\x1aMESSAGE_TYPE_SIGNER_REMOVE\x10\n\x12\x1e\n\x1aMESSAGE_TYPE_USER_DATA_ADD\x10\x0b\x12\x1f\n\x1bMESSAGE_TYPE_USERNAME_PROOF\x10\x0c*\x8a\x01\n\x10\x46\x61rcasterNetwork\x12\x1a\n\x16\x46\x41RCASTER_NETWORK_NONE\x10\x00\x12\x1d\n\x19\x46\x41RCASTER_NETWORK_MAINNET\x10\x01\x12\x1d\n\x19\x46\x41RCASTER_NETWORK_TESTNET\x10\x02\x12\x1c\n\x18\x46\x41RCASTER_NETWORK_DEVNET\x10\x03*\xa8\x01\n\x0cUserDataType\x12\x17\n\x13USER_DATA_TYPE_NONE\x10\x00\x12\x16\n\x12USER_DATA_TYPE_PFP\x10\x01\x12\x1a\n\x16USER_DATA_TYPE_DISPLAY\x10\x02\x12\x16\n\x12USER_DATA_TYPE_BIO\x10\x03\x12\x16\n\x12USER_DATA_TYPE_URL\x10\x05\x12\x1b\n\x17USER_DATA_TYPE_USERNAME\x10\x06*X\n\x0cReactionType\x12\x16\n\x12REACTION_TYPE_NONE\x10\x00\x12\x16\n\x12REACTION_TYPE_LIKE\x10\x01\x12\x18\n\x14REACTION_TYPE_RECAST\x10\x02\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "message_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_HASHSCHEME"]._serialized_start = 1646
    _globals["_HASHSCHEME"]._serialized_end = 1704
    _globals["_SIGNATURESCHEME"]._serialized_start = 1706
    _globals["_SIGNATURESCHEME"]._serialized_end = 1809
    _globals["_MESSAGETYPE"]._serialized_start = 1812
    _globals["_MESSAGETYPE"]._serialized_end = 2238
    _globals["_FARCASTERNETWORK"]._serialized_start = 2241
    _globals["_FARCASTERNETWORK"]._serialized_end = 2379
    _globals["_USERDATATYPE"]._serialized_start = 2382
    _globals["_USERDATATYPE"]._serialized_end = 2550
    _globals["_REACTIONTYPE"]._serialized_start = 2552
    _globals["_REACTIONTYPE"]._serialized_end = 2640
    _globals["_MESSAGE"]._serialized_start = 40
    _globals["_MESSAGE"]._serialized_end = 204
    _globals["_MESSAGEDATA"]._serialized_start = 207
    _globals["_MESSAGEDATA"]._serialized_end = 798
    _globals["_SIGNERADDBODY"]._serialized_start = 800
    _globals["_SIGNERADDBODY"]._serialized_end = 859
    _globals["_SIGNERREMOVEBODY"]._serialized_start = 861
    _globals["_SIGNERREMOVEBODY"]._serialized_end = 895
    _globals["_USERDATABODY"]._serialized_start = 897
    _globals["_USERDATABODY"]._serialized_end = 955
    _globals["_EMBED"]._serialized_start = 957
    _globals["_EMBED"]._serialized_end = 1016
    _globals["_CASTADDBODY"]._serialized_start = 1019
    _globals["_CASTADDBODY"]._serialized_end = 1210
    _globals["_CASTREMOVEBODY"]._serialized_start = 1212
    _globals["_CASTREMOVEBODY"]._serialized_end = 1249
    _globals["_CASTID"]._serialized_start = 1251
    _globals["_CASTID"]._serialized_end = 1286
    _globals["_REACTIONBODY"]._serialized_start = 1288
    _globals["_REACTIONBODY"]._serialized_end = 1398
    _globals["_VERIFICATIONADDETHADDRESSBODY"]._serialized_start = 1400
    _globals["_VERIFICATIONADDETHADDRESSBODY"]._serialized_end = 1491
    _globals["_VERIFICATIONREMOVEBODY"]._serialized_start = 1493
    _globals["_VERIFICATIONREMOVEBODY"]._serialized_end = 1534
    _globals["_LINKBODY"]._serialized_start = 1536
    _globals["_LINKBODY"]._serialized_end = 1644
# @@protoc_insertion_point(module_scope)



import farglot.__farcaster.generated.message_pb2 as _message_pb2
import farglot.__farcaster.generated.id_registry_event_pb2 as _id_registry_event_pb2
import farglot.__farcaster.generated.name_registry_event_pb2 as _name_registry_event_pb2
import farglot.__farcaster.generated.hub_event_pb2 as _hub_event_pb2
import farglot.__farcaster.generated.request_response_pb2 as _request_response_pb2
import farglot.__farcaster.generated.username_proof_pb2 as _username_proof_pb2
import farglot.__farcaster.generated.onchain_event_pb2 as _onchain_event_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sync_trie.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fsync_trie.proto\"J\n\nDbTrieNode\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\x12\n\nchildChars\x18\x02 \x03(\r\x12\r\n\x05items\x18\x03 \x01(\r\x12\x0c\n\x04hash\x18\x04 \x01(\x0c\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sync_trie_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DBTRIENODE']._serialized_start=19
  _globals['_DBTRIENODE']._serialized_end=93
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gossip.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import farcaster.generated.message_pb2 as message__pb2
import farcaster.generated.id_registry_event_pb2 as id__registry__event__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0cgossip.proto\x1a\rmessage.proto\x1a\x17id_registry_event.proto"T\n\x11GossipAddressInfo\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0e\n\x06\x66\x61mily\x18\x02 \x01(\r\x12\x0c\n\x04port\x18\x03 \x01(\r\x12\x10\n\x08\x64ns_name\x18\x04 \x01(\t"\xdf\x01\n\x12\x43ontactInfoContent\x12*\n\x0egossip_address\x18\x01 \x01(\x0b\x32\x12.GossipAddressInfo\x12\'\n\x0brpc_address\x18\x02 \x01(\x0b\x32\x12.GossipAddressInfo\x12\x17\n\x0f\x65xcluded_hashes\x18\x03 \x03(\t\x12\r\n\x05\x63ount\x18\x04 \x01(\r\x12\x13\n\x0bhub_version\x18\x05 \x01(\t\x12"\n\x07network\x18\x06 \x01(\x0e\x32\x11.FarcasterNetwork\x12\x13\n\x0b\x61pp_version\x18\x07 \x01(\t"F\n\x0fPingMessageBody\x12\x1b\n\x13ping_origin_peer_id\x18\x01 \x01(\x0c\x12\x16\n\x0eping_timestamp\x18\x02 \x01(\x04"x\n\x0e\x41\x63kMessageBody\x12\x1b\n\x13ping_origin_peer_id\x18\x01 \x01(\x0c\x12\x1a\n\x12\x61\x63k_origin_peer_id\x18\x02 \x01(\x0c\x12\x16\n\x0eping_timestamp\x18\x03 \x01(\x04\x12\x15\n\rack_timestamp\x18\x04 \x01(\x04"q\n\x15NetworkLatencyMessage\x12(\n\x0cping_message\x18\x02 \x01(\x0b\x32\x10.PingMessageBodyH\x00\x12&\n\x0b\x61\x63k_message\x18\x03 \x01(\x0b\x32\x0f.AckMessageBodyH\x00\x42\x06\n\x04\x62ody"\x98\x02\n\rGossipMessage\x12\x1b\n\x07message\x18\x01 \x01(\x0b\x32\x08.MessageH\x00\x12-\n\x11id_registry_event\x18\x02 \x01(\x0b\x32\x10.IdRegistryEventH\x00\x12\x33\n\x14\x63ontact_info_content\x18\x03 \x01(\x0b\x32\x13.ContactInfoContentH\x00\x12\x39\n\x17network_latency_message\x18\x07 \x01(\x0b\x32\x16.NetworkLatencyMessageH\x00\x12\x0e\n\x06topics\x18\x04 \x03(\t\x12\x0f\n\x07peer_id\x18\x05 \x01(\x0c\x12\x1f\n\x07version\x18\x06 \x01(\x0e\x32\x0e.GossipVersionB\t\n\x07\x63ontent*?\n\rGossipVersion\x12\x15\n\x11GOSSIP_VERSION_V1\x10\x00\x12\x17\n\x13GOSSIP_VERSION_V1_1\x10\x01\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "gossip_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_GOSSIPVERSION"]._serialized_start = 960
    _globals["_GOSSIPVERSION"]._serialized_end = 1023
    _globals["_GOSSIPADDRESSINFO"]._serialized_start = 56
    _globals["_GOSSIPADDRESSINFO"]._serialized_end = 140
    _globals["_CONTACTINFOCONTENT"]._serialized_start = 143
    _globals["_CONTACTINFOCONTENT"]._serialized_end = 366
    _globals["_PINGMESSAGEBODY"]._serialized_start = 368
    _globals["_PINGMESSAGEBODY"]._serialized_end = 438
    _globals["_ACKMESSAGEBODY"]._serialized_start = 440
    _globals["_ACKMESSAGEBODY"]._serialized_end = 560
    _globals["_NETWORKLATENCYMESSAGE"]._serialized_start = 562
    _globals["_NETWORKLATENCYMESSAGE"]._serialized_end = 675
    _globals["_GOSSIPMESSAGE"]._serialized_start = 678
    _globals["_GOSSIPMESSAGE"]._serialized_end = 958
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hub_event.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import farglot.__farcaster.generated.message_pb2 as message__pb2
import farglot.__farcaster.generated.id_registry_event_pb2 as id__registry__event__pb2
import farglot.__farcaster.generated.name_registry_event_pb2 as name__registry__event__pb2
import farglot.__farcaster.generated.onchain_event_pb2 as onchain__event__pb2
import farglot.__farcaster.generated.username_proof_pb2 as username__proof__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0fhub_event.proto\x1a\rmessage.proto\x1a\x17id_registry_event.proto\x1a\x19name_registry_event.proto\x1a\x13onchain_event.proto\x1a\x14username_proof.proto"Q\n\x10MergeMessageBody\x12\x19\n\x07message\x18\x01 \x01(\x0b\x32\x08.Message\x12"\n\x10\x64\x65leted_messages\x18\x02 \x03(\x0b\x32\x08.Message"-\n\x10PruneMessageBody\x12\x19\n\x07message\x18\x01 \x01(\x0b\x32\x08.Message".\n\x11RevokeMessageBody\x12\x19\n\x07message\x18\x01 \x01(\x0b\x32\x08.Message"G\n\x18MergeIdRegistryEventBody\x12+\n\x11id_registry_event\x18\x01 \x01(\x0b\x32\x10.IdRegistryEvent"M\n\x1aMergeNameRegistryEventBody\x12/\n\x13name_registry_event\x18\x01 \x01(\x0b\x32\x12.NameRegistryEvent">\n\x15MergeOnChainEventBody\x12%\n\x0eon_chain_event\x18\x01 \x01(\x0b\x32\r.OnChainEvent"\xcc\x01\n\x16MergeUserNameProofBody\x12&\n\x0eusername_proof\x18\x01 \x01(\x0b\x32\x0e.UserNameProof\x12.\n\x16\x64\x65leted_username_proof\x18\x02 \x01(\x0b\x32\x0e.UserNameProof\x12(\n\x16username_proof_message\x18\x03 \x01(\x0b\x32\x08.Message\x12\x30\n\x1e\x64\x65leted_username_proof_message\x18\x04 \x01(\x0b\x32\x08.Message"\xd5\x03\n\x08HubEvent\x12\x1b\n\x04type\x18\x01 \x01(\x0e\x32\r.HubEventType\x12\n\n\x02id\x18\x02 \x01(\x04\x12/\n\x12merge_message_body\x18\x03 \x01(\x0b\x32\x11.MergeMessageBodyH\x00\x12/\n\x12prune_message_body\x18\x04 \x01(\x0b\x32\x11.PruneMessageBodyH\x00\x12\x31\n\x13revoke_message_body\x18\x05 \x01(\x0b\x32\x12.RevokeMessageBodyH\x00\x12\x41\n\x1cmerge_id_registry_event_body\x18\x06 \x01(\x0b\x32\x19.MergeIdRegistryEventBodyH\x00\x12\x45\n\x1emerge_name_registry_event_body\x18\x07 \x01(\x0b\x32\x1b.MergeNameRegistryEventBodyH\x00\x12<\n\x19merge_username_proof_body\x18\x08 \x01(\x0b\x32\x17.MergeUserNameProofBodyH\x00\x12;\n\x19merge_on_chain_event_body\x18\x0b \x01(\x0b\x32\x16.MergeOnChainEventBodyH\x00\x42\x06\n\x04\x62ody*\xba\x02\n\x0cHubEventType\x12\x17\n\x13HUB_EVENT_TYPE_NONE\x10\x00\x12 \n\x1cHUB_EVENT_TYPE_MERGE_MESSAGE\x10\x01\x12 \n\x1cHUB_EVENT_TYPE_PRUNE_MESSAGE\x10\x02\x12!\n\x1dHUB_EVENT_TYPE_REVOKE_MESSAGE\x10\x03\x12*\n&HUB_EVENT_TYPE_MERGE_ID_REGISTRY_EVENT\x10\x04\x12,\n(HUB_EVENT_TYPE_MERGE_NAME_REGISTRY_EVENT\x10\x05\x12\'\n#HUB_EVENT_TYPE_MERGE_USERNAME_PROOF\x10\x06\x12\'\n#HUB_EVENT_TYPE_MERGE_ON_CHAIN_EVENT\x10\tb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "hub_event_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_HUBEVENTTYPE"]._serialized_start = 1203
    _globals["_HUBEVENTTYPE"]._serialized_end = 1517
    _globals["_MERGEMESSAGEBODY"]._serialized_start = 129
    _globals["_MERGEMESSAGEBODY"]._serialized_end = 210
    _globals["_PRUNEMESSAGEBODY"]._serialized_start = 212
    _globals["_PRUNEMESSAGEBODY"]._serialized_end = 257
    _globals["_REVOKEMESSAGEBODY"]._serialized_start = 259
    _globals["_REVOKEMESSAGEBODY"]._serialized_end = 305
    _globals["_MERGEIDREGISTRYEVENTBODY"]._serialized_start = 307
    _globals["_MERGEIDREGISTRYEVENTBODY"]._serialized_end = 378
    _globals["_MERGENAMEREGISTRYEVENTBODY"]._serialized_start = 380
    _globals["_MERGENAMEREGISTRYEVENTBODY"]._serialized_end = 457
    _globals["_MERGEONCHAINEVENTBODY"]._serialized_start = 459
    _globals["_MERGEONCHAINEVENTBODY"]._serialized_end = 521
    _globals["_MERGEUSERNAMEPROOFBODY"]._serialized_start = 524
    _globals["_MERGEUSERNAMEPROOFBODY"]._serialized_end = 728
    _globals["_HUBEVENT"]._serialized_start = 731
    _globals["_HUBEVENT"]._serialized_end = 1200
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NameRegistryEventType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    NAME_REGISTRY_EVENT_TYPE_NONE: _ClassVar[NameRegistryEventType]
    NAME_REGISTRY_EVENT_TYPE_TRANSFER: _ClassVar[NameRegistryEventType]
    NAME_REGISTRY_EVENT_TYPE_RENEW: _ClassVar[NameRegistryEventType]
NAME_REGISTRY_EVENT_TYPE_NONE: NameRegistryEventType
NAME_REGISTRY_EVENT_TYPE_TRANSFER: NameRegistryEventType
NAME_REGISTRY_EVENT_TYPE_RENEW: NameRegistryEventType

class NameRegistryEvent(_message.Message):
    __slots__ = ["block_number", "block_hash", "transaction_hash", "log_index", "fname", "to", "type", "expiry"]
    BLOCK_NUMBER_FIELD_NUMBER: _ClassVar[int]
    BLOCK_HASH_FIELD_NUMBER: _ClassVar[int]
    TRANSACTION_HASH_FIELD_NUMBER: _ClassVar[int]
    LOG_INDEX_FIELD_NUMBER: _ClassVar[int]
    FNAME_FIELD_NUMBER: _ClassVar[int]
    FROM_FIELD_NUMBER: _ClassVar[int]
    TO_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    EXPIRY_FIELD_NUMBER: _ClassVar[int]
    block_number: int
    block_hash: bytes
    transaction_hash: bytes
    log_index: int
    fname: bytes
    to: bytes
    type: NameRegistryEventType
    expiry: int
    def __init__(self, block_number: _Optional[int] = ..., block_hash: _Optional[bytes] = ..., transaction_hash: _Optional[bytes] = ..., log_index: _Optional[int] = ..., fname: _Optional[bytes] = ..., to: _Optional[bytes] = ..., type: _Optional[_Union[NameRegistryEventType, str]] = ..., expiry: _Optional[int] = ..., **kwargs) -> None: ...



from typing import List, Optional, Union
from typing_extensions import Self
from datasets import Dataset
from transformers import (
    AutoModelForSequenceClassification,
    BatchEncoding,
    DataCollatorWithPadding,
    PretrainedConfig,
    PreTrainedModel,
    PreTrainedTokenizerBase,
    TrainingArguments,
    Trainer,
)
from torch import nn, tensor, softmax

from farglot.analyzer.base import BaseAnalyzer
from farglot.pretrained import load_model_and_tokenizer


class AnalyzerForSequenceClassification(BaseAnalyzer):
    def __init__(
        self,
        model: Union[PreTrainedModel, nn.Module],
        tokenizer: PreTrainedTokenizerBase,
        training_args: TrainingArguments = TrainingArguments(
            output_dir=".", per_device_eval_batch_size=32
        ),
    ):
        self.model = model
        self.tokenizer = tokenizer
        self.batch_size = training_args.per_device_eval_batch_size
        self.eval_trainer = Trainer(
            model=model,
            args=training_args,
            data_collator=DataCollatorWithPadding(
                tokenizer=tokenizer, padding="longest"
            ),
        )

    def __tokenize(self, batch: Union[str, List[str]]) -> BatchEncoding:
        return self.tokenizer(
            batch["text"],
            padding=False,
            truncation=True,
            max_length=self.tokenizer.model_max_length,
        )

    @classmethod
    def from_model_name(
        cls, model_name: str, config: Optional[PretrainedConfig] = None
    ) -> Self:
        model, tokenizer = load_model_and_tokenizer(
            base_model=model_name,
            auto_model_class=AutoModelForSequenceClassification,
            config=config,
        )
        return cls(model, tokenizer)

    def predict(self, inputs: List[str]):
        # TODO(michael): Handle preprocessing
        data = {"text": [sentence for sentence in inputs]}
        dataset = Dataset.from_dict(data)
        dataset = dataset.map(self.__tokenize, batched=True, batch_size=self.batch_size)

        output = self.eval_trainer.predict(dataset)
        logits = tensor(output.predictions)
        probs = softmax(logits, dim=1).view(-1)
        id2label = self.model.config.id2label
        probas = {id2label[i]: probs[i].item() for i in id2label}
        # TODO(michael): Format probas

        return probas



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class IdRegistryEventType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    ID_REGISTRY_EVENT_TYPE_NONE: _ClassVar[IdRegistryEventType]
    ID_REGISTRY_EVENT_TYPE_REGISTER: _ClassVar[IdRegistryEventType]
    ID_REGISTRY_EVENT_TYPE_TRANSFER: _ClassVar[IdRegistryEventType]
ID_REGISTRY_EVENT_TYPE_NONE: IdRegistryEventType
ID_REGISTRY_EVENT_TYPE_REGISTER: IdRegistryEventType
ID_REGISTRY_EVENT_TYPE_TRANSFER: IdRegistryEventType

class IdRegistryEvent(_message.Message):
    __slots__ = ["block_number", "block_hash", "transaction_hash", "log_index", "fid", "to", "type"]
    BLOCK_NUMBER_FIELD_NUMBER: _ClassVar[int]
    BLOCK_HASH_FIELD_NUMBER: _ClassVar[int]
    TRANSACTION_HASH_FIELD_NUMBER: _ClassVar[int]
    LOG_INDEX_FIELD_NUMBER: _ClassVar[int]
    FID_FIELD_NUMBER: _ClassVar[int]
    TO_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    FROM_FIELD_NUMBER: _ClassVar[int]
    block_number: int
    block_hash: bytes
    transaction_hash: bytes
    log_index: int
    fid: int
    to: bytes
    type: IdRegistryEventType
    def __init__(self, block_number: _Optional[int] = ..., block_hash: _Optional[bytes] = ..., transaction_hash: _Optional[bytes] = ..., log_index: _Optional[int] = ..., fid: _Optional[int] = ..., to: _Optional[bytes] = ..., type: _Optional[_Union[IdRegistryEventType, str]] = ..., **kwargs) -> None: ...



from typing import Optional
from typing_extensions import Self
from transformers import PretrainedConfig

from farglot.__farcaster.client import get_ssl_client
from farglot.__farcaster.generated.message_pb2 import CastId, Message
from farglot.__farcaster.generated.request_response_pb2 import (
    FidRequest,
    MessagesResponse,
)
from farglot.__farcaster.generated.rpc_pb2_grpc import (
    HubServiceStub,
)
from farglot.analyzer.base import BaseAnalyzer
from farglot.analyzer.sequence_classification import AnalyzerForSequenceClassification
from farglot.analyzer.token_classification import AnalyzerForTokenClassification


class CastAnalyzer:
    def __init__(self, hub_client: HubServiceStub, analyzer: BaseAnalyzer) -> Self:
        self.analyzer = analyzer
        self.hub_client = hub_client

    @classmethod
    def sequence_analzyer_from_model_name(
        cls,
        hub_address: str,
        model_name: str,
        config: Optional[PretrainedConfig] = None,
    ) -> Self:
        return cls(
            hub_client=get_ssl_client(hub_address),
            analyzer=AnalyzerForSequenceClassification.from_model_name(
                model_name=model_name, config=config
            ),
        )

    @classmethod
    def token_analyzer_from_model_name(
        cls,
        hub_address: str,
        model_name: str,
        config: Optional[PretrainedConfig] = None,
    ) -> Self:
        return cls(
            hub_client=get_ssl_client(hub_address),
            analyzer=AnalyzerForTokenClassification.from_model_name(
                model_name=model_name, config=config
            ),
        )

    def predict_cast(self, fid: int, hash_hex: str):
        message: Message = self.hub_client.GetCast(
            CastId(fid=fid, hash=bytes.fromhex(hash_hex))
        )
        return self.analyzer.predict([message.data.cast_add_body.text])

    def predict_casts_by_fid(self, fid: int):
        request = FidRequest(fid=fid)
        response: MessagesResponse = self.hub_client.GetCastsByFid(request)
        inputs = [
            m.data.cast_add_body.text
            for m in response.messages
            if m.data.cast_add_body.text
        ]
        return self.analyzer.predict(inputs)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class RevokeMessagesBySignerJobPayload(_message.Message):
    __slots__ = ["fid", "signer"]
    FID_FIELD_NUMBER: _ClassVar[int]
    SIGNER_FIELD_NUMBER: _ClassVar[int]
    fid: int
    signer: bytes
    def __init__(self, fid: _Optional[int] = ..., signer: _Optional[bytes] = ...) -> None: ...

class UpdateNameRegistryEventExpiryJobPayload(_message.Message):
    __slots__ = ["fname"]
    FNAME_FIELD_NUMBER: _ClassVar[int]
    fname: bytes
    def __init__(self, fname: _Optional[bytes] = ...) -> None: ...



from typing import Dict, Optional, Tuple
from transformers import (
    AutoModel,
    AutoTokenizer,
    AutoConfig,
    PretrainedConfig,
    PreTrainedModel,
    PreTrainedTokenizerBase,
)

from farglot.utils import gen_label2id


def default_auto_config(base_model: str, id2label: Dict[int, str]) -> AutoConfig:
    config: PretrainedConfig = AutoConfig.from_pretrained(base_model)
    config.id2label = id2label
    config.label2id = gen_label2id(id2label)
    return config


def load_model_and_tokenizer(
    base_model: str,
    auto_model_class: AutoModel,
    max_length: int = 128,
    config: Optional[AutoConfig] = None,
) -> Tuple[PreTrainedModel, PreTrainedTokenizerBase]:
    model = auto_model_class.from_pretrained(base_model, config=config)

    tokenizer = AutoTokenizer.from_pretrained(base_model, config=config)
    tokenizer.model_max_length = max_length

    return model, tokenizer



import grpc

from farglot.__farcaster.generated.rpc_pb2_grpc import HubServiceStub


def get_insecure_client(address: str, use_async: bool = False) -> HubServiceStub:
    channel = (
        grpc.aio.insecure_channel(address)
        if use_async
        else grpc.insecure_channel(address)
    )
    return HubServiceStub(channel)


def get_ssl_client(address: str, use_async: bool = False) -> HubServiceStub:
    credentials = grpc.ssl_channel_credentials()
    channel = (
        grpc.aio.secure_channel(address, credentials=credentials)
        if use_async
        else grpc.secure_channel(address, credentials=credentials)
    )
    return HubServiceStub(channel)



import farglot.__farcaster.generated.message_pb2 as _message_pb2
import farglot.__farcaster.generated.id_registry_event_pb2 as _id_registry_event_pb2
import farglot.__farcaster.generated.name_registry_event_pb2 as _name_registry_event_pb2
import farglot.__farcaster.generated.onchain_event_pb2 as _onchain_event_pb2
import farglot.__farcaster.generated.username_proof_pb2 as _username_proof_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class HubEventType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    HUB_EVENT_TYPE_NONE: _ClassVar[HubEventType]
    HUB_EVENT_TYPE_MERGE_MESSAGE: _ClassVar[HubEventType]
    HUB_EVENT_TYPE_PRUNE_MESSAGE: _ClassVar[HubEventType]
    HUB_EVENT_TYPE_REVOKE_MESSAGE: _ClassVar[HubEventType]
    HUB_EVENT_TYPE_MERGE_ID_REGISTRY_EVENT: _ClassVar[HubEventType]
    HUB_EVENT_TYPE_MERGE_NAME_REGISTRY_EVENT: _ClassVar[HubEventType]
    HUB_EVENT_TYPE_MERGE_USERNAME_PROOF: _ClassVar[HubEventType]
    HUB_EVENT_TYPE_MERGE_ON_CHAIN_EVENT: _ClassVar[HubEventType]

HUB_EVENT_TYPE_NONE: HubEventType
HUB_EVENT_TYPE_MERGE_MESSAGE: HubEventType
HUB_EVENT_TYPE_PRUNE_MESSAGE: HubEventType
HUB_EVENT_TYPE_REVOKE_MESSAGE: HubEventType
HUB_EVENT_TYPE_MERGE_ID_REGISTRY_EVENT: HubEventType
HUB_EVENT_TYPE_MERGE_NAME_REGISTRY_EVENT: HubEventType
HUB_EVENT_TYPE_MERGE_USERNAME_PROOF: HubEventType
HUB_EVENT_TYPE_MERGE_ON_CHAIN_EVENT: HubEventType

class MergeMessageBody(_message.Message):
    __slots__ = ["message", "deleted_messages"]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    DELETED_MESSAGES_FIELD_NUMBER: _ClassVar[int]
    message: _message_pb2.Message
    deleted_messages: _containers.RepeatedCompositeFieldContainer[_message_pb2.Message]
    def __init__(
        self,
        message: _Optional[_Union[_message_pb2.Message, _Mapping]] = ...,
        deleted_messages: _Optional[
            _Iterable[_Union[_message_pb2.Message, _Mapping]]
        ] = ...,
    ) -> None: ...

class PruneMessageBody(_message.Message):
    __slots__ = ["message"]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    message: _message_pb2.Message
    def __init__(
        self, message: _Optional[_Union[_message_pb2.Message, _Mapping]] = ...
    ) -> None: ...

class RevokeMessageBody(_message.Message):
    __slots__ = ["message"]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    message: _message_pb2.Message
    def __init__(
        self, message: _Optional[_Union[_message_pb2.Message, _Mapping]] = ...
    ) -> None: ...

class MergeIdRegistryEventBody(_message.Message):
    __slots__ = ["id_registry_event"]
    ID_REGISTRY_EVENT_FIELD_NUMBER: _ClassVar[int]
    id_registry_event: _id_registry_event_pb2.IdRegistryEvent
    def __init__(
        self,
        id_registry_event: _Optional[
            _Union[_id_registry_event_pb2.IdRegistryEvent, _Mapping]
        ] = ...,
    ) -> None: ...

class MergeNameRegistryEventBody(_message.Message):
    __slots__ = ["name_registry_event"]
    NAME_REGISTRY_EVENT_FIELD_NUMBER: _ClassVar[int]
    name_registry_event: _name_registry_event_pb2.NameRegistryEvent
    def __init__(
        self,
        name_registry_event: _Optional[
            _Union[_name_registry_event_pb2.NameRegistryEvent, _Mapping]
        ] = ...,
    ) -> None: ...

class MergeOnChainEventBody(_message.Message):
    __slots__ = ["on_chain_event"]
    ON_CHAIN_EVENT_FIELD_NUMBER: _ClassVar[int]
    on_chain_event: _onchain_event_pb2.OnChainEvent
    def __init__(
        self,
        on_chain_event: _Optional[
            _Union[_onchain_event_pb2.OnChainEvent, _Mapping]
        ] = ...,
    ) -> None: ...

class MergeUserNameProofBody(_message.Message):
    __slots__ = [
        "username_proof",
        "deleted_username_proof",
        "username_proof_message",
        "deleted_username_proof_message",
    ]
    USERNAME_PROOF_FIELD_NUMBER: _ClassVar[int]
    DELETED_USERNAME_PROOF_FIELD_NUMBER: _ClassVar[int]
    USERNAME_PROOF_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    DELETED_USERNAME_PROOF_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    username_proof: _username_proof_pb2.UserNameProof
    deleted_username_proof: _username_proof_pb2.UserNameProof
    username_proof_message: _message_pb2.Message
    deleted_username_proof_message: _message_pb2.Message
    def __init__(
        self,
        username_proof: _Optional[
            _Union[_username_proof_pb2.UserNameProof, _Mapping]
        ] = ...,
        deleted_username_proof: _Optional[
            _Union[_username_proof_pb2.UserNameProof, _Mapping]
        ] = ...,
        username_proof_message: _Optional[_Union[_message_pb2.Message, _Mapping]] = ...,
        deleted_username_proof_message: _Optional[
            _Union[_message_pb2.Message, _Mapping]
        ] = ...,
    ) -> None: ...

class HubEvent(_message.Message):
    __slots__ = [
        "type",
        "id",
        "merge_message_body",
        "prune_message_body",
        "revoke_message_body",
        "merge_id_registry_event_body",
        "merge_name_registry_event_body",
        "merge_username_proof_body",
        "merge_on_chain_event_body",
    ]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    MERGE_MESSAGE_BODY_FIELD_NUMBER: _ClassVar[int]
    PRUNE_MESSAGE_BODY_FIELD_NUMBER: _ClassVar[int]
    REVOKE_MESSAGE_BODY_FIELD_NUMBER: _ClassVar[int]
    MERGE_ID_REGISTRY_EVENT_BODY_FIELD_NUMBER: _ClassVar[int]
    MERGE_NAME_REGISTRY_EVENT_BODY_FIELD_NUMBER: _ClassVar[int]
    MERGE_USERNAME_PROOF_BODY_FIELD_NUMBER: _ClassVar[int]
    MERGE_ON_CHAIN_EVENT_BODY_FIELD_NUMBER: _ClassVar[int]
    type: HubEventType
    id: int
    merge_message_body: MergeMessageBody
    prune_message_body: PruneMessageBody
    revoke_message_body: RevokeMessageBody
    merge_id_registry_event_body: MergeIdRegistryEventBody
    merge_name_registry_event_body: MergeNameRegistryEventBody
    merge_username_proof_body: MergeUserNameProofBody
    merge_on_chain_event_body: MergeOnChainEventBody
    def __init__(
        self,
        type: _Optional[_Union[HubEventType, str]] = ...,
        id: _Optional[int] = ...,
        merge_message_body: _Optional[_Union[MergeMessageBody, _Mapping]] = ...,
        prune_message_body: _Optional[_Union[PruneMessageBody, _Mapping]] = ...,
        revoke_message_body: _Optional[_Union[RevokeMessageBody, _Mapping]] = ...,
        merge_id_registry_event_body: _Optional[
            _Union[MergeIdRegistryEventBody, _Mapping]
        ] = ...,
        merge_name_registry_event_body: _Optional[
            _Union[MergeNameRegistryEventBody, _Mapping]
        ] = ...,
        merge_username_proof_body: _Optional[
            _Union[MergeUserNameProofBody, _Mapping]
        ] = ...,
        merge_on_chain_event_body: _Optional[
            _Union[MergeOnChainEventBody, _Mapping]
        ] = ...,
    ) -> None: ...



from typing import Dict, List, Union


def gen_label2id(id2label: Union[Dict[int, str], List[str]]) -> Dict[str, int]:
    if type(id2label) is list:
        return {str(i): label for i, label in enumerate(id2label)}
    else:
        return {v: k for k, v in id2label.items()}



from pathlib import Path
from plistlib import InvalidFileException
from typing import List, Optional, Tuple, Union
import csv
import json
import typer
import rocksdb

from farglot.__farcaster.generated.message_pb2 import Message

FARGLOT_DIR = Path.home().joinpath(".farglot")
FARGLOT_CONF_PATH = FARGLOT_DIR.joinpath("conf")
DEFAULT_CLASS_VALUE = 0
DEFAULT_HUB_DB_DIR = Path.home().joinpath("apps/hubble/.rocks/rocks.hub._default")


class Classifier:
    def __init__(
        self, name: str, default_value: Optional[Union[int, str]] = DEFAULT_CLASS_VALUE
    ):
        self.name = name
        self.default_value = default_value


app = typer.Typer()


@app.command()
def init():
    FARGLOT_DIR.mkdir(exist_ok=True)
    __write_paths_to_conf(FARGLOT_DIR.joinpath("classifers.json"), DEFAULT_HUB_DB_DIR)
    typer.echo(f"FarGlot configs initialized at {FARGLOT_CONF_PATH}")


@app.command(help="Set path to your Hub's RocksDB directory")
def set_hub_db_path(db_path: str):
    hub_db_path = Path(db_path)
    if not hub_db_path.exists() or not hub_db_path.is_dir():
        raise ValueError(f"${db_path} is not a valid directory")

    classifiers_path, _ = __read_paths_from_conf()
    __write_paths_to_conf(classifiers_path, hub_db_path)
    typer.echo(f"Hub DB path updated to {db_path}")


@app.command(help="Set path to JSON file with class headers")
def set_classifiers_path(classifiers_path: str):
    lp = Path(classifiers_path)
    if not lp.exists() or lp.is_dir():
        raise ValueError(f"${classifiers_path} is not a valid file")

    _, db_path = __read_paths_from_conf()
    __write_paths_to_conf(lp, db_path)
    typer.echo(f"Classifiers path updated to {classifiers_path}")


@app.command(help="Generate a new training set from your Hub")
def new_training_set(out: Optional[str] = None):
    classifiers_path, db_path = __read_paths_from_conf()
    if not classifiers_path.exists():
        raise FileNotFoundError(f"{classifiers_path}")

    typer.echo(f"Pulling classifers from ${classifiers_path} ...")
    with classifiers_path.open() as f:
        try:
            classifers_json = json.load(f)
        except:
            raise InvalidFileException(
                f"failed to decode classifers from {classifiers_path}"
            )

        if type(classifers_json) == list:
            classifers: List[dict] = classifers_json
            classifers = [
                Classifier(
                    classifier["name"],
                    classifier.get("default_value", DEFAULT_CLASS_VALUE),
                )
                for classifier in classifers
            ]
        elif type(classifers_json) == dict:
            single_classifer: dict = classifers_json
            classifers = [
                Classifier(
                    single_classifer["name"],
                    single_classifer.get("default_value", DEFAULT_CLASS_VALUE),
                )
            ]
        else:
            raise ValueError("f{classifers_json} is not valid")

    __generate_training_set_from_rocks_db(db_path, classifers, out)


def __generate_training_set_from_rocks_db(
    hub_db_path: Path, classifiers: List[Classifier], out: Optional[str] = None
):
    db = rocksdb.DB(
        str(hub_db_path),
        rocksdb.Options(create_if_missing=False),
    )

    typer.echo(f"Pulling casts from ${str(hub_db_path)} ...")
    it = db.itervalues()
    it.seek_to_first()

    out_path = Path(out) if out else FARGLOT_DIR.joinpath("training-set.csv")
    with out_path.open(mode="w") as f:
        csv_writer = csv.writer(f)

        class_names = ["hash", "text"]
        class_names.extend([classifier.name for classifier in classifiers])
        csv_writer.writerow(class_names)

        default_class_values = [classifier.default_value for classifier in classifiers]
        for serialized in it:
            try:
                m = Message()
                m.ParseFromString(serialized)
                if m.data.cast_add_body.text:
                    hash = f"0x{m.hash.hex()}"
                    text = m.data.cast_add_body.text
                    row = [hash, text]
                    row.extend(default_class_values)
                    csv_writer.writerow(row)
            except:
                # typer.echo("skpping non message type")
                continue

    typer.echo(f"training-set.csv available at ${out_path.absolute()}")


def __read_paths_from_conf() -> Tuple[Path, Path]:
    with FARGLOT_CONF_PATH.open(mode="r") as conf:
        classifiers_path = conf.readline().strip("\n")
        db_path = conf.readline().strip("\n")
    return Path(classifiers_path), Path(db_path)


def __write_paths_to_conf(classifiers_path: Path, db_path: Path):
    with FARGLOT_CONF_PATH.open(mode="w") as conf:
        conf.writelines([str(classifiers_path) + "\n", str(db_path)])


if __name__ == "__main__":
    app()



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class HubState(_message.Message):
    __slots__ = ["last_eth_block", "last_fname_proof"]
    LAST_ETH_BLOCK_FIELD_NUMBER: _ClassVar[int]
    LAST_FNAME_PROOF_FIELD_NUMBER: _ClassVar[int]
    last_eth_block: int
    last_fname_proof: int
    def __init__(self, last_eth_block: _Optional[int] = ..., last_fname_proof: _Optional[int] = ...) -> None: ...



from blake3 import blake3

from farglot.__farcaster.signers import Signer, Ed25519Signer
from farglot.__farcaster.generated.message_pb2 import (
    Message,
    MessageData,
    HashScheme,
    MessageType,
    SignerAddBody,
    CastAddBody,
)


def _make_message(data: MessageData, signer: Signer) -> Message:
    hash = blake3(data.SerializeToString()).digest(length=20)
    return Message(
        data=data,
        hash=hash,
        hash_scheme=HashScheme.HASH_SCHEME_BLAKE3,
        signature=signer.sign_hash(hash),
        signature_scheme=signer.signature_scheme(),
        signer=signer.public_key(),
    )


def make_signer_add(
    data: MessageData, signer: Signer, signer_add: Ed25519Signer
) -> Message:
    # Create a new MessageData object and copy the provided data
    message_data = MessageData()
    message_data.CopyFrom(data)
    message_data.type = MessageType.MESSAGE_TYPE_SIGNER_ADD
    message_data.signer_add_body.CopyFrom(SignerAddBody(signer=signer_add.public_key()))
    return _make_message(
        message_data,
        signer,
    )


def make_cast_add(data: MessageData, signer: Signer, cast_add: CastAddBody) -> Message:
    # Create a new MessageData object and copy the provided data
    message_data = MessageData()
    message_data.CopyFrom(data)
    message_data.type = MessageType.MESSAGE_TYPE_CAST_ADD
    message_data.cast_add_body.CopyFrom(cast_add)
    return _make_message(
        message_data,
        signer,
    )



import time
from typing import Optional
from datetime import datetime

FARCASTER_EPOCH = 1609459200000  # January 1, 2021 UTC


def get_farcaster_time() -> Optional[int]:
    return to_farcaster_time(time.time_ns() // 1_000_000)


def to_farcaster_time(time: int) -> Optional[int]:
    if time < FARCASTER_EPOCH:
        # time must be after Farcaster epoch (01/01/2022)
        return None

    seconds_since_epoch = (time - FARCASTER_EPOCH) // 1000

    if seconds_since_epoch > (2**32) - 1:
        # time too far in future
        return None

    return seconds_since_epoch


def from_farcaster_time(time: int) -> int:
    return (time * 1000) + FARCASTER_EPOCH


def datetime_from_farcaster_time(time: int) -> datetime:
    return datetime.fromtimestamp(from_farcaster_time(time) / 1_000)



import farglot.__farcaster.generated.username_proof_pb2 as _username_proof_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class HashScheme(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    HASH_SCHEME_NONE: _ClassVar[HashScheme]
    HASH_SCHEME_BLAKE3: _ClassVar[HashScheme]

class SignatureScheme(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    SIGNATURE_SCHEME_NONE: _ClassVar[SignatureScheme]
    SIGNATURE_SCHEME_ED25519: _ClassVar[SignatureScheme]
    SIGNATURE_SCHEME_EIP712: _ClassVar[SignatureScheme]

class MessageType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    MESSAGE_TYPE_NONE: _ClassVar[MessageType]
    MESSAGE_TYPE_CAST_ADD: _ClassVar[MessageType]
    MESSAGE_TYPE_CAST_REMOVE: _ClassVar[MessageType]
    MESSAGE_TYPE_REACTION_ADD: _ClassVar[MessageType]
    MESSAGE_TYPE_REACTION_REMOVE: _ClassVar[MessageType]
    MESSAGE_TYPE_LINK_ADD: _ClassVar[MessageType]
    MESSAGE_TYPE_LINK_REMOVE: _ClassVar[MessageType]
    MESSAGE_TYPE_VERIFICATION_ADD_ETH_ADDRESS: _ClassVar[MessageType]
    MESSAGE_TYPE_VERIFICATION_REMOVE: _ClassVar[MessageType]
    MESSAGE_TYPE_SIGNER_ADD: _ClassVar[MessageType]
    MESSAGE_TYPE_SIGNER_REMOVE: _ClassVar[MessageType]
    MESSAGE_TYPE_USER_DATA_ADD: _ClassVar[MessageType]
    MESSAGE_TYPE_USERNAME_PROOF: _ClassVar[MessageType]

class FarcasterNetwork(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    FARCASTER_NETWORK_NONE: _ClassVar[FarcasterNetwork]
    FARCASTER_NETWORK_MAINNET: _ClassVar[FarcasterNetwork]
    FARCASTER_NETWORK_TESTNET: _ClassVar[FarcasterNetwork]
    FARCASTER_NETWORK_DEVNET: _ClassVar[FarcasterNetwork]

class UserDataType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    USER_DATA_TYPE_NONE: _ClassVar[UserDataType]
    USER_DATA_TYPE_PFP: _ClassVar[UserDataType]
    USER_DATA_TYPE_DISPLAY: _ClassVar[UserDataType]
    USER_DATA_TYPE_BIO: _ClassVar[UserDataType]
    USER_DATA_TYPE_URL: _ClassVar[UserDataType]
    USER_DATA_TYPE_USERNAME: _ClassVar[UserDataType]

class ReactionType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    REACTION_TYPE_NONE: _ClassVar[ReactionType]
    REACTION_TYPE_LIKE: _ClassVar[ReactionType]
    REACTION_TYPE_RECAST: _ClassVar[ReactionType]

HASH_SCHEME_NONE: HashScheme
HASH_SCHEME_BLAKE3: HashScheme
SIGNATURE_SCHEME_NONE: SignatureScheme
SIGNATURE_SCHEME_ED25519: SignatureScheme
SIGNATURE_SCHEME_EIP712: SignatureScheme
MESSAGE_TYPE_NONE: MessageType
MESSAGE_TYPE_CAST_ADD: MessageType
MESSAGE_TYPE_CAST_REMOVE: MessageType
MESSAGE_TYPE_REACTION_ADD: MessageType
MESSAGE_TYPE_REACTION_REMOVE: MessageType
MESSAGE_TYPE_LINK_ADD: MessageType
MESSAGE_TYPE_LINK_REMOVE: MessageType
MESSAGE_TYPE_VERIFICATION_ADD_ETH_ADDRESS: MessageType
MESSAGE_TYPE_VERIFICATION_REMOVE: MessageType
MESSAGE_TYPE_SIGNER_ADD: MessageType
MESSAGE_TYPE_SIGNER_REMOVE: MessageType
MESSAGE_TYPE_USER_DATA_ADD: MessageType
MESSAGE_TYPE_USERNAME_PROOF: MessageType
FARCASTER_NETWORK_NONE: FarcasterNetwork
FARCASTER_NETWORK_MAINNET: FarcasterNetwork
FARCASTER_NETWORK_TESTNET: FarcasterNetwork
FARCASTER_NETWORK_DEVNET: FarcasterNetwork
USER_DATA_TYPE_NONE: UserDataType
USER_DATA_TYPE_PFP: UserDataType
USER_DATA_TYPE_DISPLAY: UserDataType
USER_DATA_TYPE_BIO: UserDataType
USER_DATA_TYPE_URL: UserDataType
USER_DATA_TYPE_USERNAME: UserDataType
REACTION_TYPE_NONE: ReactionType
REACTION_TYPE_LIKE: ReactionType
REACTION_TYPE_RECAST: ReactionType

class Message(_message.Message):
    __slots__ = [
        "data",
        "hash",
        "hash_scheme",
        "signature",
        "signature_scheme",
        "signer",
    ]
    DATA_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    HASH_SCHEME_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_SCHEME_FIELD_NUMBER: _ClassVar[int]
    SIGNER_FIELD_NUMBER: _ClassVar[int]
    data: MessageData
    hash: bytes
    hash_scheme: HashScheme
    signature: bytes
    signature_scheme: SignatureScheme
    signer: bytes
    def __init__(
        self,
        data: _Optional[_Union[MessageData, _Mapping]] = ...,
        hash: _Optional[bytes] = ...,
        hash_scheme: _Optional[_Union[HashScheme, str]] = ...,
        signature: _Optional[bytes] = ...,
        signature_scheme: _Optional[_Union[SignatureScheme, str]] = ...,
        signer: _Optional[bytes] = ...,
    ) -> None: ...

class MessageData(_message.Message):
    __slots__ = [
        "type",
        "fid",
        "timestamp",
        "network",
        "cast_add_body",
        "cast_remove_body",
        "reaction_body",
        "verification_add_eth_address_body",
        "verification_remove_body",
        "signer_add_body",
        "user_data_body",
        "signer_remove_body",
        "link_body",
        "username_proof_body",
    ]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    FID_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    NETWORK_FIELD_NUMBER: _ClassVar[int]
    CAST_ADD_BODY_FIELD_NUMBER: _ClassVar[int]
    CAST_REMOVE_BODY_FIELD_NUMBER: _ClassVar[int]
    REACTION_BODY_FIELD_NUMBER: _ClassVar[int]
    VERIFICATION_ADD_ETH_ADDRESS_BODY_FIELD_NUMBER: _ClassVar[int]
    VERIFICATION_REMOVE_BODY_FIELD_NUMBER: _ClassVar[int]
    SIGNER_ADD_BODY_FIELD_NUMBER: _ClassVar[int]
    USER_DATA_BODY_FIELD_NUMBER: _ClassVar[int]
    SIGNER_REMOVE_BODY_FIELD_NUMBER: _ClassVar[int]
    LINK_BODY_FIELD_NUMBER: _ClassVar[int]
    USERNAME_PROOF_BODY_FIELD_NUMBER: _ClassVar[int]
    type: MessageType
    fid: int
    timestamp: int
    network: FarcasterNetwork
    cast_add_body: CastAddBody
    cast_remove_body: CastRemoveBody
    reaction_body: ReactionBody
    verification_add_eth_address_body: VerificationAddEthAddressBody
    verification_remove_body: VerificationRemoveBody
    signer_add_body: SignerAddBody
    user_data_body: UserDataBody
    signer_remove_body: SignerRemoveBody
    link_body: LinkBody
    username_proof_body: _username_proof_pb2.UserNameProof
    def __init__(
        self,
        type: _Optional[_Union[MessageType, str]] = ...,
        fid: _Optional[int] = ...,
        timestamp: _Optional[int] = ...,
        network: _Optional[_Union[FarcasterNetwork, str]] = ...,
        cast_add_body: _Optional[_Union[CastAddBody, _Mapping]] = ...,
        cast_remove_body: _Optional[_Union[CastRemoveBody, _Mapping]] = ...,
        reaction_body: _Optional[_Union[ReactionBody, _Mapping]] = ...,
        verification_add_eth_address_body: _Optional[
            _Union[VerificationAddEthAddressBody, _Mapping]
        ] = ...,
        verification_remove_body: _Optional[
            _Union[VerificationRemoveBody, _Mapping]
        ] = ...,
        signer_add_body: _Optional[_Union[SignerAddBody, _Mapping]] = ...,
        user_data_body: _Optional[_Union[UserDataBody, _Mapping]] = ...,
        signer_remove_body: _Optional[_Union[SignerRemoveBody, _Mapping]] = ...,
        link_body: _Optional[_Union[LinkBody, _Mapping]] = ...,
        username_proof_body: _Optional[
            _Union[_username_proof_pb2.UserNameProof, _Mapping]
        ] = ...,
    ) -> None: ...

class SignerAddBody(_message.Message):
    __slots__ = ["signer", "name"]
    SIGNER_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    signer: bytes
    name: str
    def __init__(
        self, signer: _Optional[bytes] = ..., name: _Optional[str] = ...
    ) -> None: ...

class SignerRemoveBody(_message.Message):
    __slots__ = ["signer"]
    SIGNER_FIELD_NUMBER: _ClassVar[int]
    signer: bytes
    def __init__(self, signer: _Optional[bytes] = ...) -> None: ...

class UserDataBody(_message.Message):
    __slots__ = ["type", "value"]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    type: UserDataType
    value: str
    def __init__(
        self,
        type: _Optional[_Union[UserDataType, str]] = ...,
        value: _Optional[str] = ...,
    ) -> None: ...

class Embed(_message.Message):
    __slots__ = ["url", "cast_id"]
    URL_FIELD_NUMBER: _ClassVar[int]
    CAST_ID_FIELD_NUMBER: _ClassVar[int]
    url: str
    cast_id: CastId
    def __init__(
        self,
        url: _Optional[str] = ...,
        cast_id: _Optional[_Union[CastId, _Mapping]] = ...,
    ) -> None: ...

class CastAddBody(_message.Message):
    __slots__ = [
        "embeds_deprecated",
        "mentions",
        "parent_cast_id",
        "parent_url",
        "text",
        "mentions_positions",
        "embeds",
    ]
    EMBEDS_DEPRECATED_FIELD_NUMBER: _ClassVar[int]
    MENTIONS_FIELD_NUMBER: _ClassVar[int]
    PARENT_CAST_ID_FIELD_NUMBER: _ClassVar[int]
    PARENT_URL_FIELD_NUMBER: _ClassVar[int]
    TEXT_FIELD_NUMBER: _ClassVar[int]
    MENTIONS_POSITIONS_FIELD_NUMBER: _ClassVar[int]
    EMBEDS_FIELD_NUMBER: _ClassVar[int]
    embeds_deprecated: _containers.RepeatedScalarFieldContainer[str]
    mentions: _containers.RepeatedScalarFieldContainer[int]
    parent_cast_id: CastId
    parent_url: str
    text: str
    mentions_positions: _containers.RepeatedScalarFieldContainer[int]
    embeds: _containers.RepeatedCompositeFieldContainer[Embed]
    def __init__(
        self,
        embeds_deprecated: _Optional[_Iterable[str]] = ...,
        mentions: _Optional[_Iterable[int]] = ...,
        parent_cast_id: _Optional[_Union[CastId, _Mapping]] = ...,
        parent_url: _Optional[str] = ...,
        text: _Optional[str] = ...,
        mentions_positions: _Optional[_Iterable[int]] = ...,
        embeds: _Optional[_Iterable[_Union[Embed, _Mapping]]] = ...,
    ) -> None: ...

class CastRemoveBody(_message.Message):
    __slots__ = ["target_hash"]
    TARGET_HASH_FIELD_NUMBER: _ClassVar[int]
    target_hash: bytes
    def __init__(self, target_hash: _Optional[bytes] = ...) -> None: ...

class CastId(_message.Message):
    __slots__ = ["fid", "hash"]
    FID_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    fid: int
    hash: bytes
    def __init__(
        self, fid: _Optional[int] = ..., hash: _Optional[bytes] = ...
    ) -> None: ...

class ReactionBody(_message.Message):
    __slots__ = ["type", "target_cast_id", "target_url"]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    TARGET_CAST_ID_FIELD_NUMBER: _ClassVar[int]
    TARGET_URL_FIELD_NUMBER: _ClassVar[int]
    type: ReactionType
    target_cast_id: CastId
    target_url: str
    def __init__(
        self,
        type: _Optional[_Union[ReactionType, str]] = ...,
        target_cast_id: _Optional[_Union[CastId, _Mapping]] = ...,
        target_url: _Optional[str] = ...,
    ) -> None: ...

class VerificationAddEthAddressBody(_message.Message):
    __slots__ = ["address", "eth_signature", "block_hash"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    ETH_SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    BLOCK_HASH_FIELD_NUMBER: _ClassVar[int]
    address: bytes
    eth_signature: bytes
    block_hash: bytes
    def __init__(
        self,
        address: _Optional[bytes] = ...,
        eth_signature: _Optional[bytes] = ...,
        block_hash: _Optional[bytes] = ...,
    ) -> None: ...

class VerificationRemoveBody(_message.Message):
    __slots__ = ["address"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    address: bytes
    def __init__(self, address: _Optional[bytes] = ...) -> None: ...

class LinkBody(_message.Message):
    __slots__ = ["type", "displayTimestamp", "target_fid"]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    DISPLAYTIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    TARGET_FID_FIELD_NUMBER: _ClassVar[int]
    type: str
    displayTimestamp: int
    target_fid: int
    def __init__(
        self,
        type: _Optional[str] = ...,
        displayTimestamp: _Optional[int] = ...,
        target_fid: _Optional[int] = ...,
    ) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: request_response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import farglot.__farcaster.generated.message_pb2 as message__pb2
import farglot.__farcaster.generated.onchain_event_pb2 as onchain__event__pb2
import farglot.__farcaster.generated.hub_event_pb2 as hub__event__pb2
import farglot.__farcaster.generated.username_proof_pb2 as username__proof__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x16request_response.proto\x1a\rmessage.proto\x1a\x13onchain_event.proto\x1a\x0fhub_event.proto\x1a\x14username_proof.proto"\x07\n\x05\x45mpty"X\n\x10SubscribeRequest\x12"\n\x0b\x65vent_types\x18\x01 \x03(\x0e\x32\r.HubEventType\x12\x14\n\x07\x66rom_id\x18\x02 \x01(\x04H\x00\x88\x01\x01\x42\n\n\x08_from_id"\x1a\n\x0c\x45ventRequest\x12\n\n\x02id\x18\x01 \x01(\x04""\n\x0eHubInfoRequest\x12\x10\n\x08\x64\x62_stats\x18\x01 \x01(\x08"w\n\x0fHubInfoResponse\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x12\n\nis_syncing\x18\x02 \x01(\x08\x12\x10\n\x08nickname\x18\x03 \x01(\t\x12\x11\n\troot_hash\x18\x04 \x01(\t\x12\x1a\n\x08\x64\x62_stats\x18\x05 \x01(\x0b\x32\x08.DbStats"Q\n\x07\x44\x62Stats\x12\x14\n\x0cnum_messages\x18\x01 \x01(\x04\x12\x16\n\x0enum_fid_events\x18\x02 \x01(\x04\x12\x18\n\x10num_fname_events\x18\x03 \x01(\x04"3\n\x11SyncStatusRequest\x12\x13\n\x06peerId\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\t\n\x07_peerId"b\n\x12SyncStatusResponse\x12\x12\n\nis_syncing\x18\x01 \x01(\x08\x12 \n\x0bsync_status\x18\x02 \x03(\x0b\x32\x0b.SyncStatus\x12\x16\n\x0e\x65ngine_started\x18\x03 \x01(\x08"\xb9\x01\n\nSyncStatus\x12\x0e\n\x06peerId\x18\x01 \x01(\t\x12\x0e\n\x06inSync\x18\x02 \x01(\t\x12\x12\n\nshouldSync\x18\x03 \x01(\x08\x12\x18\n\x10\x64ivergencePrefix\x18\x04 \x01(\t\x12\x1c\n\x14\x64ivergenceSecondsAgo\x18\x05 \x01(\x05\x12\x15\n\rtheirMessages\x18\x06 \x01(\x04\x12\x13\n\x0bourMessages\x18\x07 \x01(\x04\x12\x13\n\x0blastBadSync\x18\x08 \x01(\x03"{\n\x18TrieNodeMetadataResponse\x12\x0e\n\x06prefix\x18\x01 \x01(\x0c\x12\x14\n\x0cnum_messages\x18\x02 \x01(\x04\x12\x0c\n\x04hash\x18\x03 \x01(\t\x12+\n\x08\x63hildren\x18\x04 \x03(\x0b\x32\x19.TrieNodeMetadataResponse"l\n\x18TrieNodeSnapshotResponse\x12\x0e\n\x06prefix\x18\x01 \x01(\x0c\x12\x17\n\x0f\x65xcluded_hashes\x18\x02 \x03(\t\x12\x14\n\x0cnum_messages\x18\x03 \x01(\x04\x12\x11\n\troot_hash\x18\x04 \x01(\t" \n\x0eTrieNodePrefix\x12\x0e\n\x06prefix\x18\x01 \x01(\x0c"\x1b\n\x07SyncIds\x12\x10\n\x08sync_ids\x18\x01 \x03(\x0c"\x89\x01\n\nFidRequest\x12\x0b\n\x03\x66id\x18\x01 \x01(\x04\x12\x16\n\tpage_size\x18\x02 \x01(\rH\x00\x88\x01\x01\x12\x17\n\npage_token\x18\x03 \x01(\x0cH\x01\x88\x01\x01\x12\x14\n\x07reverse\x18\x04 \x01(\x08H\x02\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\n\n\x08_reverse"}\n\x0b\x46idsRequest\x12\x16\n\tpage_size\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x17\n\npage_token\x18\x02 \x01(\x0cH\x01\x88\x01\x01\x12\x14\n\x07reverse\x18\x03 \x01(\x08H\x02\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\n\n\x08_reverse"N\n\x0c\x46idsResponse\x12\x0c\n\x04\x66ids\x18\x01 \x03(\x04\x12\x1c\n\x0fnext_page_token\x18\x02 \x01(\x0cH\x00\x88\x01\x01\x42\x12\n\x10_next_page_token"`\n\x10MessagesResponse\x12\x1a\n\x08messages\x18\x01 \x03(\x0b\x32\x08.Message\x12\x1c\n\x0fnext_page_token\x18\x02 \x01(\x0cH\x00\x88\x01\x01\x42\x12\n\x10_next_page_token"\xc9\x01\n\x14\x43\x61stsByParentRequest\x12!\n\x0eparent_cast_id\x18\x01 \x01(\x0b\x32\x07.CastIdH\x00\x12\x14\n\nparent_url\x18\x05 \x01(\tH\x00\x12\x16\n\tpage_size\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x17\n\npage_token\x18\x03 \x01(\x0cH\x02\x88\x01\x01\x12\x14\n\x07reverse\x18\x04 \x01(\x08H\x03\x88\x01\x01\x42\x08\n\x06parentB\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\n\n\x08_reverse"\x87\x01\n\x0fReactionRequest\x12\x0b\n\x03\x66id\x18\x01 \x01(\x04\x12$\n\rreaction_type\x18\x02 \x01(\x0e\x32\r.ReactionType\x12!\n\x0etarget_cast_id\x18\x03 \x01(\x0b\x32\x07.CastIdH\x00\x12\x14\n\ntarget_url\x18\x04 \x01(\tH\x00\x42\x08\n\x06target"\xd1\x01\n\x15ReactionsByFidRequest\x12\x0b\n\x03\x66id\x18\x01 \x01(\x04\x12)\n\rreaction_type\x18\x02 \x01(\x0e\x32\r.ReactionTypeH\x00\x88\x01\x01\x12\x16\n\tpage_size\x18\x03 \x01(\rH\x01\x88\x01\x01\x12\x17\n\npage_token\x18\x04 \x01(\x0cH\x02\x88\x01\x01\x12\x14\n\x07reverse\x18\x05 \x01(\x08H\x03\x88\x01\x01\x42\x10\n\x0e_reaction_typeB\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\n\n\x08_reverse"\x8a\x02\n\x18ReactionsByTargetRequest\x12!\n\x0etarget_cast_id\x18\x01 \x01(\x0b\x32\x07.CastIdH\x00\x12\x14\n\ntarget_url\x18\x06 \x01(\tH\x00\x12)\n\rreaction_type\x18\x02 \x01(\x0e\x32\r.ReactionTypeH\x01\x88\x01\x01\x12\x16\n\tpage_size\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x17\n\npage_token\x18\x04 \x01(\x0cH\x03\x88\x01\x01\x12\x14\n\x07reverse\x18\x05 \x01(\x08H\x04\x88\x01\x01\x42\x08\n\x06targetB\x10\n\x0e_reaction_typeB\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\n\n\x08_reverse"E\n\x0fUserDataRequest\x12\x0b\n\x03\x66id\x18\x01 \x01(\x04\x12%\n\x0euser_data_type\x18\x02 \x01(\x0e\x32\r.UserDataType"(\n\x18NameRegistryEventRequest\x12\x0c\n\x04name\x18\x01 \x01(\x0c"(\n\x19RentRegistryEventsRequest\x12\x0b\n\x03\x66id\x18\x01 \x01(\x04"I\n\x13OnChainEventRequest\x12\x0b\n\x03\x66id\x18\x01 \x01(\x04\x12%\n\nevent_type\x18\x02 \x01(\x0e\x32\x11.OnChainEventType"5\n\x14OnChainEventResponse\x12\x1d\n\x06\x65vents\x18\x01 \x03(\x0b\x32\r.OnChainEvent"6\n\x15StorageLimitsResponse\x12\x1d\n\x06limits\x18\x01 \x03(\x0b\x32\r.StorageLimit"=\n\x0cStorageLimit\x12\x1e\n\nstore_type\x18\x01 \x01(\x0e\x32\n.StoreType\x12\r\n\x05limit\x18\x02 \x01(\x04"$\n\x14UsernameProofRequest\x12\x0c\n\x04name\x18\x01 \x01(\x0c"8\n\x16UsernameProofsResponse\x12\x1e\n\x06proofs\x18\x01 \x03(\x0b\x32\x0e.UserNameProof"3\n\x13VerificationRequest\x12\x0b\n\x03\x66id\x18\x01 \x01(\x04\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0c",\n\rSignerRequest\x12\x0b\n\x03\x66id\x18\x01 \x01(\x04\x12\x0e\n\x06signer\x18\x02 \x01(\x0c"M\n\x0bLinkRequest\x12\x0b\n\x03\x66id\x18\x01 \x01(\x04\x12\x11\n\tlink_type\x18\x02 \x01(\t\x12\x14\n\ntarget_fid\x18\x03 \x01(\x04H\x00\x42\x08\n\x06target"\xb6\x01\n\x11LinksByFidRequest\x12\x0b\n\x03\x66id\x18\x01 \x01(\x04\x12\x16\n\tlink_type\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tpage_size\x18\x03 \x01(\rH\x01\x88\x01\x01\x12\x17\n\npage_token\x18\x04 \x01(\x0cH\x02\x88\x01\x01\x12\x14\n\x07reverse\x18\x05 \x01(\x08H\x03\x88\x01\x01\x42\x0c\n\n_link_typeB\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\n\n\x08_reverse"\xcc\x01\n\x14LinksByTargetRequest\x12\x14\n\ntarget_fid\x18\x01 \x01(\x04H\x00\x12\x16\n\tlink_type\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x16\n\tpage_size\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x17\n\npage_token\x18\x04 \x01(\x0cH\x03\x88\x01\x01\x12\x14\n\x07reverse\x18\x05 \x01(\x08H\x04\x88\x01\x01\x42\x08\n\x06targetB\x0c\n\n_link_typeB\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\n\n\x08_reverse"%\n\x16IdRegistryEventRequest\x12\x0b\n\x03\x66id\x18\x01 \x01(\x04"2\n\x1fIdRegistryEventByAddressRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c*\x9e\x01\n\tStoreType\x12\x13\n\x0fSTORE_TYPE_NONE\x10\x00\x12\x14\n\x10STORE_TYPE_CASTS\x10\x01\x12\x14\n\x10STORE_TYPE_LINKS\x10\x02\x12\x18\n\x14STORE_TYPE_REACTIONS\x10\x03\x12\x18\n\x14STORE_TYPE_USER_DATA\x10\x04\x12\x1c\n\x18STORE_TYPE_VERIFICATIONS\x10\x05\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "request_response_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_STORETYPE"]._serialized_start = 3537
    _globals["_STORETYPE"]._serialized_end = 3695
    _globals["_EMPTY"]._serialized_start = 101
    _globals["_EMPTY"]._serialized_end = 108
    _globals["_SUBSCRIBEREQUEST"]._serialized_start = 110
    _globals["_SUBSCRIBEREQUEST"]._serialized_end = 198
    _globals["_EVENTREQUEST"]._serialized_start = 200
    _globals["_EVENTREQUEST"]._serialized_end = 226
    _globals["_HUBINFOREQUEST"]._serialized_start = 228
    _globals["_HUBINFOREQUEST"]._serialized_end = 262
    _globals["_HUBINFORESPONSE"]._serialized_start = 264
    _globals["_HUBINFORESPONSE"]._serialized_end = 383
    _globals["_DBSTATS"]._serialized_start = 385
    _globals["_DBSTATS"]._serialized_end = 466
    _globals["_SYNCSTATUSREQUEST"]._serialized_start = 468
    _globals["_SYNCSTATUSREQUEST"]._serialized_end = 519
    _globals["_SYNCSTATUSRESPONSE"]._serialized_start = 521
    _globals["_SYNCSTATUSRESPONSE"]._serialized_end = 619
    _globals["_SYNCSTATUS"]._serialized_start = 622
    _globals["_SYNCSTATUS"]._serialized_end = 807
    _globals["_TRIENODEMETADATARESPONSE"]._serialized_start = 809
    _globals["_TRIENODEMETADATARESPONSE"]._serialized_end = 932
    _globals["_TRIENODESNAPSHOTRESPONSE"]._serialized_start = 934
    _globals["_TRIENODESNAPSHOTRESPONSE"]._serialized_end = 1042
    _globals["_TRIENODEPREFIX"]._serialized_start = 1044
    _globals["_TRIENODEPREFIX"]._serialized_end = 1076
    _globals["_SYNCIDS"]._serialized_start = 1078
    _globals["_SYNCIDS"]._serialized_end = 1105
    _globals["_FIDREQUEST"]._serialized_start = 1108
    _globals["_FIDREQUEST"]._serialized_end = 1245
    _globals["_FIDSREQUEST"]._serialized_start = 1247
    _globals["_FIDSREQUEST"]._serialized_end = 1372
    _globals["_FIDSRESPONSE"]._serialized_start = 1374
    _globals["_FIDSRESPONSE"]._serialized_end = 1452
    _globals["_MESSAGESRESPONSE"]._serialized_start = 1454
    _globals["_MESSAGESRESPONSE"]._serialized_end = 1550
    _globals["_CASTSBYPARENTREQUEST"]._serialized_start = 1553
    _globals["_CASTSBYPARENTREQUEST"]._serialized_end = 1754
    _globals["_REACTIONREQUEST"]._serialized_start = 1757
    _globals["_REACTIONREQUEST"]._serialized_end = 1892
    _globals["_REACTIONSBYFIDREQUEST"]._serialized_start = 1895
    _globals["_REACTIONSBYFIDREQUEST"]._serialized_end = 2104
    _globals["_REACTIONSBYTARGETREQUEST"]._serialized_start = 2107
    _globals["_REACTIONSBYTARGETREQUEST"]._serialized_end = 2373
    _globals["_USERDATAREQUEST"]._serialized_start = 2375
    _globals["_USERDATAREQUEST"]._serialized_end = 2444
    _globals["_NAMEREGISTRYEVENTREQUEST"]._serialized_start = 2446
    _globals["_NAMEREGISTRYEVENTREQUEST"]._serialized_end = 2486
    _globals["_RENTREGISTRYEVENTSREQUEST"]._serialized_start = 2488
    _globals["_RENTREGISTRYEVENTSREQUEST"]._serialized_end = 2528
    _globals["_ONCHAINEVENTREQUEST"]._serialized_start = 2530
    _globals["_ONCHAINEVENTREQUEST"]._serialized_end = 2603
    _globals["_ONCHAINEVENTRESPONSE"]._serialized_start = 2605
    _globals["_ONCHAINEVENTRESPONSE"]._serialized_end = 2658
    _globals["_STORAGELIMITSRESPONSE"]._serialized_start = 2660
    _globals["_STORAGELIMITSRESPONSE"]._serialized_end = 2714
    _globals["_STORAGELIMIT"]._serialized_start = 2716
    _globals["_STORAGELIMIT"]._serialized_end = 2777
    _globals["_USERNAMEPROOFREQUEST"]._serialized_start = 2779
    _globals["_USERNAMEPROOFREQUEST"]._serialized_end = 2815
    _globals["_USERNAMEPROOFSRESPONSE"]._serialized_start = 2817
    _globals["_USERNAMEPROOFSRESPONSE"]._serialized_end = 2873
    _globals["_VERIFICATIONREQUEST"]._serialized_start = 2875
    _globals["_VERIFICATIONREQUEST"]._serialized_end = 2926
    _globals["_SIGNERREQUEST"]._serialized_start = 2928
    _globals["_SIGNERREQUEST"]._serialized_end = 2972
    _globals["_LINKREQUEST"]._serialized_start = 2974
    _globals["_LINKREQUEST"]._serialized_end = 3051
    _globals["_LINKSBYFIDREQUEST"]._serialized_start = 3054
    _globals["_LINKSBYFIDREQUEST"]._serialized_end = 3236
    _globals["_LINKSBYTARGETREQUEST"]._serialized_start = 3239
    _globals["_LINKSBYTARGETREQUEST"]._serialized_end = 3443
    _globals["_IDREGISTRYEVENTREQUEST"]._serialized_start = 3445
    _globals["_IDREGISTRYEVENTREQUEST"]._serialized_end = 3482
    _globals["_IDREGISTRYEVENTBYADDRESSREQUEST"]._serialized_start = 3484
    _globals["_IDREGISTRYEVENTBYADDRESSREQUEST"]._serialized_end = 3534
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hub_state.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fhub_state.proto\"<\n\x08HubState\x12\x16\n\x0elast_eth_block\x18\x01 \x01(\r\x12\x18\n\x10last_fname_proof\x18\x02 \x01(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hub_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_HUBSTATE']._serialized_start=19
  _globals['_HUBSTATE']._serialized_end=79
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: onchain_event.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13onchain_event.proto\"\xa7\x03\n\x0cOnChainEvent\x12\x1f\n\x04type\x18\x01 \x01(\x0e\x32\x11.OnChainEventType\x12\x10\n\x08\x63hain_id\x18\x02 \x01(\r\x12\x14\n\x0c\x62lock_number\x18\x03 \x01(\r\x12\x12\n\nblock_hash\x18\x04 \x01(\x0c\x12\x17\n\x0f\x62lock_timestamp\x18\x05 \x01(\x04\x12\x18\n\x10transaction_hash\x18\x06 \x01(\x0c\x12\x11\n\tlog_index\x18\x07 \x01(\r\x12\x0b\n\x03\x66id\x18\x08 \x01(\x04\x12-\n\x11signer_event_body\x18\t \x01(\x0b\x32\x10.SignerEventBodyH\x00\x12>\n\x1asigner_migrated_event_body\x18\n \x01(\x0b\x32\x18.SignerMigratedEventBodyH\x00\x12\x36\n\x16id_register_event_body\x18\x0b \x01(\x0b\x32\x14.IdRegisterEventBodyH\x00\x12\x38\n\x17storage_rent_event_body\x18\x0c \x01(\x0b\x32\x15.StorageRentEventBodyH\x00\x42\x06\n\x04\x62ody\"f\n\x0fSignerEventBody\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\x0e\n\x06scheme\x18\x02 \x01(\r\x12$\n\nevent_type\x18\x03 \x01(\x0e\x32\x10.SignerEventType\x12\x10\n\x08metadata\x18\x04 \x01(\x0c\"-\n\x17SignerMigratedEventBody\x12\x12\n\nmigratedAt\x18\x01 \x01(\r\"s\n\x13IdRegisterEventBody\x12\n\n\x02to\x18\x01 \x01(\x0c\x12(\n\nevent_type\x18\x02 \x01(\x0e\x32\x14.IdRegisterEventType\x12\x0c\n\x04\x66rom\x18\x03 \x01(\x0c\x12\x18\n\x10recovery_address\x18\x04 \x01(\x0c\"D\n\x14StorageRentEventBody\x12\r\n\x05payer\x18\x01 \x01(\x0c\x12\r\n\x05units\x18\x02 \x01(\r\x12\x0e\n\x06\x65xpiry\x18\x03 \x01(\r*\x97\x01\n\x10OnChainEventType\x12\x13\n\x0f\x45VENT_TYPE_NONE\x10\x00\x12\x15\n\x11\x45VENT_TYPE_SIGNER\x10\x01\x12\x1e\n\x1a\x45VENT_TYPE_SIGNER_MIGRATED\x10\x02\x12\x1a\n\x16\x45VENT_TYPE_ID_REGISTER\x10\x03\x12\x1b\n\x17\x45VENT_TYPE_STORAGE_RENT\x10\x04*\x89\x01\n\x0fSignerEventType\x12\x1a\n\x16SIGNER_EVENT_TYPE_NONE\x10\x00\x12\x19\n\x15SIGNER_EVENT_TYPE_ADD\x10\x01\x12\x1c\n\x18SIGNER_EVENT_TYPE_REMOVE\x10\x02\x12!\n\x1dSIGNER_EVENT_TYPE_ADMIN_RESET\x10\x03*\xac\x01\n\x13IdRegisterEventType\x12\x1f\n\x1bID_REGISTER_EVENT_TYPE_NONE\x10\x00\x12#\n\x1fID_REGISTER_EVENT_TYPE_REGISTER\x10\x01\x12#\n\x1fID_REGISTER_EVENT_TYPE_TRANSFER\x10\x02\x12*\n&ID_REGISTER_EVENT_TYPE_CHANGE_RECOVERY\x10\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'onchain_event_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ONCHAINEVENTTYPE']._serialized_start=788
  _globals['_ONCHAINEVENTTYPE']._serialized_end=939
  _globals['_SIGNEREVENTTYPE']._serialized_start=942
  _globals['_SIGNEREVENTTYPE']._serialized_end=1079
  _globals['_IDREGISTEREVENTTYPE']._serialized_start=1082
  _globals['_IDREGISTEREVENTTYPE']._serialized_end=1254
  _globals['_ONCHAINEVENT']._serialized_start=24
  _globals['_ONCHAINEVENT']._serialized_end=447
  _globals['_SIGNEREVENTBODY']._serialized_start=449
  _globals['_SIGNEREVENTBODY']._serialized_end=551
  _globals['_SIGNERMIGRATEDEVENTBODY']._serialized_start=553
  _globals['_SIGNERMIGRATEDEVENTBODY']._serialized_end=598
  _globals['_IDREGISTEREVENTBODY']._serialized_start=600
  _globals['_IDREGISTEREVENTBODY']._serialized_end=715
  _globals['_STORAGERENTEVENTBODY']._serialized_start=717
  _globals['_STORAGERENTEVENTBODY']._serialized_end=785
# @@protoc_insertion_point(module_scope)



import os
from datasets import load_dataset

from examples.classifiers.binary import binary_classifier

CHECKPOINTS_DIR = f"{os.getcwd()}/data/checkpoints"

dataset = load_dataset(
    "csv", data_files={"test": "data/test-set.csv", "train": "data/training-set.csv"}
)
trainer = binary_classifier("distilbert-base-uncased")


# PREPROCESS DATA
def preprocess_function(batch):
    tokenized_batch = trainer.tokenizer(
        batch["text"],
        padding=True,
        truncation=True,
    )
    tokenized_batch["labels"] = [
        trainer.model.config.label2id[label] for label in batch["labels"]
    ]
    return tokenized_batch


trainer.train_dataset = dataset["train"].map(preprocess_function, batched=True)
trainer.eval_dataset = dataset["test"].map(preprocess_function, batched=True)

# SET TRAINING PARAMS

trainer.args.output_dir = CHECKPOINTS_DIR
trainer.args.eval_steps = 20
trainer.args.evaluation_strategy = "steps"
trainer.args.report_to = "wandb"
trainer.args.learning_rate = 2e-5
trainer.args.logging_steps = 5
trainer.args.per_device_train_batch_size = 16
trainer.args.per_device_eval_batch_size = 16
trainer.args.num_train_epochs = 2
trainer.args.weight_decay = 0.01
trainer.args.save_strategy = "epoch"

# TRAIN DATASETS

trainer.train()

# RUN EVALUATION AND RETURN METRICS

trainer.evaluate()



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UserNameType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    USERNAME_TYPE_NONE: _ClassVar[UserNameType]
    USERNAME_TYPE_FNAME: _ClassVar[UserNameType]
    USERNAME_TYPE_ENS_L1: _ClassVar[UserNameType]
USERNAME_TYPE_NONE: UserNameType
USERNAME_TYPE_FNAME: UserNameType
USERNAME_TYPE_ENS_L1: UserNameType

class UserNameProof(_message.Message):
    __slots__ = ["timestamp", "name", "owner", "signature", "fid", "type"]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    OWNER_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    FID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    timestamp: int
    name: bytes
    owner: bytes
    signature: bytes
    fid: int
    type: UserNameType
    def __init__(self, timestamp: _Optional[int] = ..., name: _Optional[bytes] = ..., owner: _Optional[bytes] = ..., signature: _Optional[bytes] = ..., fid: _Optional[int] = ..., type: _Optional[_Union[UserNameType, str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rpc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import farglot.__farcaster.generated.message_pb2 as message__pb2
import farglot.__farcaster.generated.id_registry_event_pb2 as id__registry__event__pb2
import farglot.__farcaster.generated.name_registry_event_pb2 as name__registry__event__pb2
import farglot.__farcaster.generated.hub_event_pb2 as hub__event__pb2
import farglot.__farcaster.generated.request_response_pb2 as request__response__pb2
import farglot.__farcaster.generated.username_proof_pb2 as username__proof__pb2
import farglot.__farcaster.generated.onchain_event_pb2 as onchain__event__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b"\n\trpc.proto\x1a\rmessage.proto\x1a\x17id_registry_event.proto\x1a\x19name_registry_event.proto\x1a\x0fhub_event.proto\x1a\x16request_response.proto\x1a\x14username_proof.proto\x1a\x13onchain_event.proto2\x86\x12\n\nHubService\x12#\n\rSubmitMessage\x12\x08.Message\x1a\x08.Message\x12+\n\tSubscribe\x12\x11.SubscribeRequest\x1a\t.HubEvent0\x01\x12$\n\x08GetEvent\x12\r.EventRequest\x1a\t.HubEvent\x12\x1c\n\x07GetCast\x12\x07.CastId\x1a\x08.Message\x12/\n\rGetCastsByFid\x12\x0b.FidRequest\x1a\x11.MessagesResponse\x12<\n\x10GetCastsByParent\x12\x15.CastsByParentRequest\x1a\x11.MessagesResponse\x12\x33\n\x11GetCastsByMention\x12\x0b.FidRequest\x1a\x11.MessagesResponse\x12)\n\x0bGetReaction\x12\x10.ReactionRequest\x1a\x08.Message\x12>\n\x11GetReactionsByFid\x12\x16.ReactionsByFidRequest\x1a\x11.MessagesResponse\x12\x42\n\x12GetReactionsByCast\x12\x19.ReactionsByTargetRequest\x1a\x11.MessagesResponse\x12\x44\n\x14GetReactionsByTarget\x12\x19.ReactionsByTargetRequest\x1a\x11.MessagesResponse\x12)\n\x0bGetUserData\x12\x10.UserDataRequest\x1a\x08.Message\x12\x32\n\x10GetUserDataByFid\x12\x0b.FidRequest\x1a\x11.MessagesResponse\x12\x45\n\x14GetNameRegistryEvent\x12\x19.NameRegistryEventRequest\x1a\x12.NameRegistryEvent\x12?\n\x10GetOnChainEvents\x12\x14.OnChainEventRequest\x1a\x15.OnChainEventResponse\x12\x43\n\x1cGetCurrentStorageLimitsByFid\x12\x0b.FidRequest\x1a\x16.StorageLimitsResponse\x12\x39\n\x10GetUsernameProof\x12\x15.UsernameProofRequest\x1a\x0e.UserNameProof\x12>\n\x16GetUserNameProofsByFid\x12\x0b.FidRequest\x1a\x17.UsernameProofsResponse\x12\x31\n\x0fGetVerification\x12\x14.VerificationRequest\x1a\x08.Message\x12\x37\n\x15GetVerificationsByFid\x12\x0b.FidRequest\x1a\x11.MessagesResponse\x12%\n\tGetSigner\x12\x0e.SignerRequest\x1a\x08.Message\x12\x31\n\x10GetOnChainSigner\x12\x0e.SignerRequest\x1a\r.OnChainEvent\x12\x31\n\x0fGetSignersByFid\x12\x0b.FidRequest\x1a\x11.MessagesResponse\x12?\n\x12GetIdRegistryEvent\x12\x17.IdRegistryEventRequest\x1a\x10.IdRegistryEvent\x12Q\n\x1bGetIdRegistryEventByAddress\x12 .IdRegistryEventByAddressRequest\x1a\x10.IdRegistryEvent\x12&\n\x07GetFids\x12\x0c.FidsRequest\x1a\r.FidsResponse\x12!\n\x07GetLink\x12\x0c.LinkRequest\x1a\x08.Message\x12\x36\n\rGetLinksByFid\x12\x12.LinksByFidRequest\x1a\x11.MessagesResponse\x12<\n\x10GetLinksByTarget\x12\x15.LinksByTargetRequest\x1a\x11.MessagesResponse\x12\x39\n\x17GetAllCastMessagesByFid\x12\x0b.FidRequest\x1a\x11.MessagesResponse\x12=\n\x1bGetAllReactionMessagesByFid\x12\x0b.FidRequest\x1a\x11.MessagesResponse\x12\x41\n\x1fGetAllVerificationMessagesByFid\x12\x0b.FidRequest\x1a\x11.MessagesResponse\x12;\n\x19GetAllSignerMessagesByFid\x12\x0b.FidRequest\x1a\x11.MessagesResponse\x12=\n\x1bGetAllUserDataMessagesByFid\x12\x0b.FidRequest\x1a\x11.MessagesResponse\x12\x39\n\x17GetAllLinkMessagesByFid\x12\x0b.FidRequest\x1a\x11.MessagesResponse\x12,\n\x07GetInfo\x12\x0f.HubInfoRequest\x1a\x10.HubInfoResponse\x12\x38\n\rGetSyncStatus\x12\x12.SyncStatusRequest\x1a\x13.SyncStatusResponse\x12\x32\n\x15GetAllSyncIdsByPrefix\x12\x0f.TrieNodePrefix\x1a\x08.SyncIds\x12\x36\n\x17GetAllMessagesBySyncIds\x12\x08.SyncIds\x1a\x11.MessagesResponse\x12\x45\n\x17GetSyncMetadataByPrefix\x12\x0f.TrieNodePrefix\x1a\x19.TrieNodeMetadataResponse\x12\x45\n\x17GetSyncSnapshotByPrefix\x12\x0f.TrieNodePrefix\x1a\x19.TrieNodeSnapshotResponse2\x90\x02\n\x0c\x41\x64minService\x12!\n\x0fRebuildSyncTrie\x12\x06.Empty\x1a\x06.Empty\x12)\n\x17\x44\x65leteAllMessagesFromDb\x12\x06.Empty\x1a\x06.Empty\x12;\n\x15SubmitIdRegistryEvent\x12\x10.IdRegistryEvent\x1a\x10.IdRegistryEvent\x12\x41\n\x17SubmitNameRegistryEvent\x12\x12.NameRegistryEvent\x1a\x12.NameRegistryEvent\x12\x32\n\x12SubmitOnChainEvent\x12\r.OnChainEvent\x1a\r.OnChainEventb\x06proto3"
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "rpc_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_HUBSERVICE"]._serialized_start = 165
    _globals["_HUBSERVICE"]._serialized_end = 2475
    _globals["_ADMINSERVICE"]._serialized_start = 2478
    _globals["_ADMINSERVICE"]._serialized_end = 2750
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class OnChainEventType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    EVENT_TYPE_NONE: _ClassVar[OnChainEventType]
    EVENT_TYPE_SIGNER: _ClassVar[OnChainEventType]
    EVENT_TYPE_SIGNER_MIGRATED: _ClassVar[OnChainEventType]
    EVENT_TYPE_ID_REGISTER: _ClassVar[OnChainEventType]
    EVENT_TYPE_STORAGE_RENT: _ClassVar[OnChainEventType]

class SignerEventType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    SIGNER_EVENT_TYPE_NONE: _ClassVar[SignerEventType]
    SIGNER_EVENT_TYPE_ADD: _ClassVar[SignerEventType]
    SIGNER_EVENT_TYPE_REMOVE: _ClassVar[SignerEventType]
    SIGNER_EVENT_TYPE_ADMIN_RESET: _ClassVar[SignerEventType]

class IdRegisterEventType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    ID_REGISTER_EVENT_TYPE_NONE: _ClassVar[IdRegisterEventType]
    ID_REGISTER_EVENT_TYPE_REGISTER: _ClassVar[IdRegisterEventType]
    ID_REGISTER_EVENT_TYPE_TRANSFER: _ClassVar[IdRegisterEventType]
    ID_REGISTER_EVENT_TYPE_CHANGE_RECOVERY: _ClassVar[IdRegisterEventType]
EVENT_TYPE_NONE: OnChainEventType
EVENT_TYPE_SIGNER: OnChainEventType
EVENT_TYPE_SIGNER_MIGRATED: OnChainEventType
EVENT_TYPE_ID_REGISTER: OnChainEventType
EVENT_TYPE_STORAGE_RENT: OnChainEventType
SIGNER_EVENT_TYPE_NONE: SignerEventType
SIGNER_EVENT_TYPE_ADD: SignerEventType
SIGNER_EVENT_TYPE_REMOVE: SignerEventType
SIGNER_EVENT_TYPE_ADMIN_RESET: SignerEventType
ID_REGISTER_EVENT_TYPE_NONE: IdRegisterEventType
ID_REGISTER_EVENT_TYPE_REGISTER: IdRegisterEventType
ID_REGISTER_EVENT_TYPE_TRANSFER: IdRegisterEventType
ID_REGISTER_EVENT_TYPE_CHANGE_RECOVERY: IdRegisterEventType

class OnChainEvent(_message.Message):
    __slots__ = ["type", "chain_id", "block_number", "block_hash", "block_timestamp", "transaction_hash", "log_index", "fid", "signer_event_body", "signer_migrated_event_body", "id_register_event_body", "storage_rent_event_body"]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    CHAIN_ID_FIELD_NUMBER: _ClassVar[int]
    BLOCK_NUMBER_FIELD_NUMBER: _ClassVar[int]
    BLOCK_HASH_FIELD_NUMBER: _ClassVar[int]
    BLOCK_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    TRANSACTION_HASH_FIELD_NUMBER: _ClassVar[int]
    LOG_INDEX_FIELD_NUMBER: _ClassVar[int]
    FID_FIELD_NUMBER: _ClassVar[int]
    SIGNER_EVENT_BODY_FIELD_NUMBER: _ClassVar[int]
    SIGNER_MIGRATED_EVENT_BODY_FIELD_NUMBER: _ClassVar[int]
    ID_REGISTER_EVENT_BODY_FIELD_NUMBER: _ClassVar[int]
    STORAGE_RENT_EVENT_BODY_FIELD_NUMBER: _ClassVar[int]
    type: OnChainEventType
    chain_id: int
    block_number: int
    block_hash: bytes
    block_timestamp: int
    transaction_hash: bytes
    log_index: int
    fid: int
    signer_event_body: SignerEventBody
    signer_migrated_event_body: SignerMigratedEventBody
    id_register_event_body: IdRegisterEventBody
    storage_rent_event_body: StorageRentEventBody
    def __init__(self, type: _Optional[_Union[OnChainEventType, str]] = ..., chain_id: _Optional[int] = ..., block_number: _Optional[int] = ..., block_hash: _Optional[bytes] = ..., block_timestamp: _Optional[int] = ..., transaction_hash: _Optional[bytes] = ..., log_index: _Optional[int] = ..., fid: _Optional[int] = ..., signer_event_body: _Optional[_Union[SignerEventBody, _Mapping]] = ..., signer_migrated_event_body: _Optional[_Union[SignerMigratedEventBody, _Mapping]] = ..., id_register_event_body: _Optional[_Union[IdRegisterEventBody, _Mapping]] = ..., storage_rent_event_body: _Optional[_Union[StorageRentEventBody, _Mapping]] = ...) -> None: ...

class SignerEventBody(_message.Message):
    __slots__ = ["key", "scheme", "event_type", "metadata"]
    KEY_FIELD_NUMBER: _ClassVar[int]
    SCHEME_FIELD_NUMBER: _ClassVar[int]
    EVENT_TYPE_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    key: bytes
    scheme: int
    event_type: SignerEventType
    metadata: bytes
    def __init__(self, key: _Optional[bytes] = ..., scheme: _Optional[int] = ..., event_type: _Optional[_Union[SignerEventType, str]] = ..., metadata: _Optional[bytes] = ...) -> None: ...

class SignerMigratedEventBody(_message.Message):
    __slots__ = ["migratedAt"]
    MIGRATEDAT_FIELD_NUMBER: _ClassVar[int]
    migratedAt: int
    def __init__(self, migratedAt: _Optional[int] = ...) -> None: ...

class IdRegisterEventBody(_message.Message):
    __slots__ = ["to", "event_type", "recovery_address"]
    TO_FIELD_NUMBER: _ClassVar[int]
    EVENT_TYPE_FIELD_NUMBER: _ClassVar[int]
    FROM_FIELD_NUMBER: _ClassVar[int]
    RECOVERY_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    to: bytes
    event_type: IdRegisterEventType
    recovery_address: bytes
    def __init__(self, to: _Optional[bytes] = ..., event_type: _Optional[_Union[IdRegisterEventType, str]] = ..., recovery_address: _Optional[bytes] = ..., **kwargs) -> None: ...

class StorageRentEventBody(_message.Message):
    __slots__ = ["payer", "units", "expiry"]
    PAYER_FIELD_NUMBER: _ClassVar[int]
    UNITS_FIELD_NUMBER: _ClassVar[int]
    EXPIRY_FIELD_NUMBER: _ClassVar[int]
    payer: bytes
    units: int
    expiry: int
    def __init__(self, payer: _Optional[bytes] = ..., units: _Optional[int] = ..., expiry: _Optional[int] = ...) -> None: ...
